@@ -18,6 +18,7 @@ class Adapter_For_MAM(Basic_Adapter):
         "ESTStart": "est_start",
         "TVODStart": "tvod_start",
         "PVODStart": "premium_vod_start",
+        "PESTStart": "premium_est_start",
         "DVDStart": "dvd_start",
         "Kinostart": "theatrical_start",
         "Quality": "quality",
@@ -58,6 +59,7 @@ class Adapter_For_MAM(Basic_Adapter):
         "ESTEnde": "est_end",
         "TVODEnde": "tvod_end",
         "PVODEnde": "premium_vod_end",
+        "PESTEnde": "premium_est_end",
         "Holdback_EST_Start": "holdback_est_start",
         "Holdback_EST_End": "holdback_est_end",
         "Holdback_TVOD_Start": "holdback_tvod_start",
@@ -80,6 +82,7 @@ class Adapter_For_MAM(Basic_Adapter):
         "channel_type": "channel_type",  # muss implementiert werden
         "mandant": "mandant",
         "deal_type": "deal_type",
+        "theatrical_admissions": "theatrical_admissions",
     }
     metadata_dict = {
         "VendorID": "vendor_id",
@@ -89,4 +92,5 @@ class Adapter_For_MAM(Basic_Adapter):
         'Titel': 'titel_local',
         'Originaltitel': 'titel_ov',
         'trailer_link': 'trailer_link',
+        'pf_specific_id_sky': 'pf_specific_id_sky',
     }
